Defaults
========

.. automodule:: psyneulink.core.globals.defaults
   :members: defaultControlAllocation include-private
   :private-members:
   :exclude-members: random

   :autodata: defaultControlAllocation, Parameters
